# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rtabmap_msgs/srv/get_nodes_in_radius.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/rtabmap_msgs/srv/get_nodes_in_radius.proto\x12+make87_messages_ros2.jazzy.rtabmap_msgs.srv\x1a\x37make87_messages_ros2/jazzy/geometry_msgs/msg/pose.proto\"f\n\x17GetNodesInRadiusRequest\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\x12\t\n\x01x\x18\x02 \x01(\x02\x12\t\n\x01y\x18\x03 \x01(\x02\x12\t\n\x01z\x18\x04 \x01(\x02\x12\x0e\n\x06radius\x18\x05 \x01(\x02\x12\t\n\x01k\x18\x06 \x01(\x05\"}\n\x18GetNodesInRadiusResponse\x12\x0b\n\x03ids\x18\x01 \x03(\x05\x12\x41\n\x05poses\x18\x02 \x03(\x0b\x32\x32.make87_messages_ros2.jazzy.geometry_msgs.msg.Pose\x12\x11\n\tdists_sqr\x18\x03 \x03(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rtabmap_msgs.srv.get_nodes_in_radius_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETNODESINRADIUSREQUEST']._serialized_start=175
  _globals['_GETNODESINRADIUSREQUEST']._serialized_end=277
  _globals['_GETNODESINRADIUSRESPONSE']._serialized_start=279
  _globals['_GETNODESINRADIUSRESPONSE']._serialized_end=404
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geographic_msgs.msg import key_value_pb2 as _key_value_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from make87_messages_ros2.humble.unique_identifier_msgs.msg import uuid_pb2 as _uuid_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RoutePath(_message.Message):
    __slots__ = ("header", "ros2_header", "network", "segments", "props")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    NETWORK_FIELD_NUMBER: _ClassVar[int]
    SEGMENTS_FIELD_NUMBER: _ClassVar[int]
    PROPS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    network: _uuid_pb2.UUID
    segments: _containers.RepeatedCompositeFieldContainer[_uuid_pb2.UUID]
    props: _containers.RepeatedCompositeFieldContainer[_key_value_pb2.KeyValue]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., network: _Optional[_Union[_uuid_pb2.UUID, _Mapping]] = ..., segments: _Optional[_Iterable[_Union[_uuid_pb2.UUID, _Mapping]]] = ..., props: _Optional[_Iterable[_Union[_key_value_pb2.KeyValue, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.rmf_fleet_msgs.msg import delivery_alert_action_pb2 as _delivery_alert_action_pb2
from make87_messages_ros2.jazzy.rmf_fleet_msgs.msg import delivery_alert_category_pb2 as _delivery_alert_category_pb2
from make87_messages_ros2.jazzy.rmf_fleet_msgs.msg import delivery_alert_tier_pb2 as _delivery_alert_tier_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DeliveryAlert(_message.Message):
    __slots__ = ("id", "category", "tier", "task_id", "action", "message")
    ID_FIELD_NUMBER: _ClassVar[int]
    CATEGORY_FIELD_NUMBER: _ClassVar[int]
    TIER_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    id: str
    category: _delivery_alert_category_pb2.DeliveryAlertCategory
    tier: _delivery_alert_tier_pb2.DeliveryAlertTier
    task_id: str
    action: _delivery_alert_action_pb2.DeliveryAlertAction
    message: str
    def __init__(self, id: _Optional[str] = ..., category: _Optional[_Union[_delivery_alert_category_pb2.DeliveryAlertCategory, _Mapping]] = ..., tier: _Optional[_Union[_delivery_alert_tier_pb2.DeliveryAlertTier, _Mapping]] = ..., task_id: _Optional[str] = ..., action: _Optional[_Union[_delivery_alert_action_pb2.DeliveryAlertAction, _Mapping]] = ..., message: _Optional[str] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.scenario_execution_interfaces.msg import scenario_pb2 as _scenario_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ScenarioList(_message.Message):
    __slots__ = ("header", "scenarios")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SCENARIOS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    scenarios: _containers.RepeatedCompositeFieldContainer[_scenario_pb2.Scenario]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., scenarios: _Optional[_Iterable[_Union[_scenario_pb2.Scenario, _Mapping]]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Entity(_message.Message):
    __slots__ = ("entity_type", "name", "types")
    ENTITY_TYPE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPES_FIELD_NUMBER: _ClassVar[int]
    entity_type: int
    name: str
    types: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, entity_type: _Optional[int] = ..., name: _Optional[str] = ..., types: _Optional[_Iterable[str]] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BaseConstr(_message.Message):
    __slots__ = ("header", "v_max", "av_max", "w_max", "aw_max", "omg_wh_max")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    V_MAX_FIELD_NUMBER: _ClassVar[int]
    AV_MAX_FIELD_NUMBER: _ClassVar[int]
    W_MAX_FIELD_NUMBER: _ClassVar[int]
    AW_MAX_FIELD_NUMBER: _ClassVar[int]
    OMG_WH_MAX_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    v_max: float
    av_max: float
    w_max: float
    aw_max: float
    omg_wh_max: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., v_max: _Optional[float] = ..., av_max: _Optional[float] = ..., w_max: _Optional[float] = ..., aw_max: _Optional[float] = ..., omg_wh_max: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ur_msgs/msg/masterboard_data_msg.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/humble/ur_msgs/msg/masterboard_data_msg.proto\x12\'make87_messages_ros2.humble.ur_msgs.msg\x1a!make87_messages/core/header.proto\"\xf8\x03\n\x12MasterboardDataMsg\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x1a\n\x12\x64igital_input_bits\x18\x02 \x01(\r\x12\x1b\n\x13\x64igital_output_bits\x18\x03 \x01(\r\x12\x1b\n\x13\x61nalog_input_range0\x18\x04 \x01(\x05\x12\x1b\n\x13\x61nalog_input_range1\x18\x05 \x01(\x05\x12\x15\n\ranalog_input0\x18\x06 \x01(\x01\x12\x15\n\ranalog_input1\x18\x07 \x01(\x01\x12\x1d\n\x15\x61nalog_output_domain0\x18\x08 \x01(\x05\x12\x1d\n\x15\x61nalog_output_domain1\x18\t \x01(\x05\x12\x16\n\x0e\x61nalog_output0\x18\n \x01(\x01\x12\x16\n\x0e\x61nalog_output1\x18\x0b \x01(\x01\x12\x1f\n\x17masterboard_temperature\x18\x0c \x01(\x02\x12\x19\n\x11robot_voltage_48v\x18\r \x01(\x02\x12\x15\n\rrobot_current\x18\x0e \x01(\x02\x12\x19\n\x11master_io_current\x18\x0f \x01(\x02\x12\x1b\n\x13master_safety_state\x18\x10 \x01(\r\x12\x1a\n\x12master_onoff_state\x18\x11 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ur_msgs.msg.masterboard_data_msg_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MASTERBOARDDATAMSG']._serialized_start=147
  _globals['_MASTERBOARDDATAMSG']._serialized_end=651
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/cartographer_ros_msgs/msg/metric.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.cartographer_ros_msgs.msg import histogram_bucket_pb2 as make87__messages__ros2_dot_jazzy_dot_cartographer__ros__msgs_dot_msg_dot_histogram__bucket__pb2
from make87_messages_ros2.jazzy.cartographer_ros_msgs.msg import metric_label_pb2 as make87__messages__ros2_dot_jazzy_dot_cartographer__ros__msgs_dot_msg_dot_metric__label__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/cartographer_ros_msgs/msg/metric.proto\x12\x34make87_messages_ros2.jazzy.cartographer_ros_msgs.msg\x1aKmake87_messages_ros2/jazzy/cartographer_ros_msgs/msg/histogram_bucket.proto\x1aGmake87_messages_ros2/jazzy/cartographer_ros_msgs/msg/metric_label.proto\"\xd9\x01\n\x06Metric\x12\x0c\n\x04type\x18\x01 \x01(\r\x12Q\n\x06labels\x18\x02 \x03(\x0b\x32\x41.make87_messages_ros2.jazzy.cartographer_ros_msgs.msg.MetricLabel\x12\r\n\x05value\x18\x03 \x01(\x01\x12_\n\x10\x63ounts_by_bucket\x18\x04 \x03(\x0b\x32\x45.make87_messages_ros2.jazzy.cartographer_ros_msgs.msg.HistogramBucketb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.cartographer_ros_msgs.msg.metric_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_METRIC']._serialized_start=274
  _globals['_METRIC']._serialized_end=491
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.geographic_msgs.msg import geographic_map_changes_pb2 as _geographic_map_changes_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UpdateGeographicMapRequest(_message.Message):
    __slots__ = ("updates",)
    UPDATES_FIELD_NUMBER: _ClassVar[int]
    updates: _geographic_map_changes_pb2.GeographicMapChanges
    def __init__(self, updates: _Optional[_Union[_geographic_map_changes_pb2.GeographicMapChanges, _Mapping]] = ...) -> None: ...

class UpdateGeographicMapResponse(_message.Message):
    __slots__ = ("success", "status")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    status: str
    def __init__(self, success: bool = ..., status: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class AidHUI(_message.Message):
    __slots__ = ("health", "utc_a0", "utc_a1", "utc_tow", "utc_wnt", "utc_ls", "utc_wnf", "utc_dn", "utc_lsf", "utc_spare", "klob_a0", "klob_a1", "klob_a2", "klob_a3", "klob_b0", "klob_b1", "klob_b2", "klob_b3", "flags")
    HEALTH_FIELD_NUMBER: _ClassVar[int]
    UTC_A0_FIELD_NUMBER: _ClassVar[int]
    UTC_A1_FIELD_NUMBER: _ClassVar[int]
    UTC_TOW_FIELD_NUMBER: _ClassVar[int]
    UTC_WNT_FIELD_NUMBER: _ClassVar[int]
    UTC_LS_FIELD_NUMBER: _ClassVar[int]
    UTC_WNF_FIELD_NUMBER: _ClassVar[int]
    UTC_DN_FIELD_NUMBER: _ClassVar[int]
    UTC_LSF_FIELD_NUMBER: _ClassVar[int]
    UTC_SPARE_FIELD_NUMBER: _ClassVar[int]
    KLOB_A0_FIELD_NUMBER: _ClassVar[int]
    KLOB_A1_FIELD_NUMBER: _ClassVar[int]
    KLOB_A2_FIELD_NUMBER: _ClassVar[int]
    KLOB_A3_FIELD_NUMBER: _ClassVar[int]
    KLOB_B0_FIELD_NUMBER: _ClassVar[int]
    KLOB_B1_FIELD_NUMBER: _ClassVar[int]
    KLOB_B2_FIELD_NUMBER: _ClassVar[int]
    KLOB_B3_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    health: int
    utc_a0: float
    utc_a1: float
    utc_tow: int
    utc_wnt: int
    utc_ls: int
    utc_wnf: int
    utc_dn: int
    utc_lsf: int
    utc_spare: int
    klob_a0: float
    klob_a1: float
    klob_a2: float
    klob_a3: float
    klob_b0: float
    klob_b1: float
    klob_b2: float
    klob_b3: float
    flags: int
    def __init__(self, health: _Optional[int] = ..., utc_a0: _Optional[float] = ..., utc_a1: _Optional[float] = ..., utc_tow: _Optional[int] = ..., utc_wnt: _Optional[int] = ..., utc_ls: _Optional[int] = ..., utc_wnf: _Optional[int] = ..., utc_dn: _Optional[int] = ..., utc_lsf: _Optional[int] = ..., utc_spare: _Optional[int] = ..., klob_a0: _Optional[float] = ..., klob_a1: _Optional[float] = ..., klob_a2: _Optional[float] = ..., klob_a3: _Optional[float] = ..., klob_b0: _Optional[float] = ..., klob_b1: _Optional[float] = ..., klob_b2: _Optional[float] = ..., klob_b3: _Optional[float] = ..., flags: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MrrStatusTempVolt(_message.Message):
    __slots__ = ("header", "can_batt_volts", "can_1_25_v", "can_5_v", "can_3_3_v_raw", "can_3_3_v_dac", "can_mmic_temp1", "can_processor_thermistor", "can_processor_temp1")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CAN_BATT_VOLTS_FIELD_NUMBER: _ClassVar[int]
    CAN_1_25_V_FIELD_NUMBER: _ClassVar[int]
    CAN_5_V_FIELD_NUMBER: _ClassVar[int]
    CAN_3_3_V_RAW_FIELD_NUMBER: _ClassVar[int]
    CAN_3_3_V_DAC_FIELD_NUMBER: _ClassVar[int]
    CAN_MMIC_TEMP1_FIELD_NUMBER: _ClassVar[int]
    CAN_PROCESSOR_THERMISTOR_FIELD_NUMBER: _ClassVar[int]
    CAN_PROCESSOR_TEMP1_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    can_batt_volts: float
    can_1_25_v: float
    can_5_v: float
    can_3_3_v_raw: float
    can_3_3_v_dac: float
    can_mmic_temp1: int
    can_processor_thermistor: int
    can_processor_temp1: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., can_batt_volts: _Optional[float] = ..., can_1_25_v: _Optional[float] = ..., can_5_v: _Optional[float] = ..., can_3_3_v_raw: _Optional[float] = ..., can_3_3_v_dac: _Optional[float] = ..., can_mmic_temp1: _Optional[int] = ..., can_processor_thermistor: _Optional[int] = ..., can_processor_temp1: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.rmf_task_msgs.msg import assignment_pb2 as _assignment_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DispatchState(_message.Message):
    __slots__ = ("task_id", "status", "assignment", "errors")
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    ASSIGNMENT_FIELD_NUMBER: _ClassVar[int]
    ERRORS_FIELD_NUMBER: _ClassVar[int]
    task_id: str
    status: int
    assignment: _assignment_pb2.Assignment
    errors: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, task_id: _Optional[str] = ..., status: _Optional[int] = ..., assignment: _Optional[_Union[_assignment_pb2.Assignment, _Mapping]] = ..., errors: _Optional[_Iterable[str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/moveit_msgs/msg/cartesian_trajectory_point.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import duration_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_duration__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import cartesian_point_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_cartesian__point__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMmake87_messages_ros2/rolling/moveit_msgs/msg/cartesian_trajectory_point.proto\x12,make87_messages_ros2.rolling.moveit_msgs.msg\x1a\x42make87_messages_ros2/rolling/builtin_interfaces/msg/duration.proto\x1a\x42make87_messages_ros2/rolling/moveit_msgs/msg/cartesian_point.proto\"\xbf\x01\n\x18\x43\x61rtesianTrajectoryPoint\x12K\n\x05point\x18\x01 \x01(\x0b\x32<.make87_messages_ros2.rolling.moveit_msgs.msg.CartesianPoint\x12V\n\x0ftime_from_start\x18\x02 \x01(\x0b\x32=.make87_messages_ros2.rolling.builtin_interfaces.msg.Durationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.moveit_msgs.msg.cartesian_trajectory_point_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CARTESIANTRAJECTORYPOINT']._serialized_start=264
  _globals['_CARTESIANTRAJECTORYPOINT']._serialized_end=455
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/autoware_sensing_msgs/msg/gnss_ins_orientation.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import quaternion_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_quaternion__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQmake87_messages_ros2/rolling/autoware_sensing_msgs/msg/gnss_ins_orientation.proto\x12\x36make87_messages_ros2.rolling.autoware_sensing_msgs.msg\x1a?make87_messages_ros2/rolling/geometry_msgs/msg/quaternion.proto\"\xb0\x01\n\x12GnssInsOrientation\x12O\n\x0borientation\x18\x01 \x01(\x0b\x32:.make87_messages_ros2.rolling.geometry_msgs.msg.Quaternion\x12\x17\n\x0frmse_rotation_x\x18\x02 \x01(\x02\x12\x17\n\x0frmse_rotation_y\x18\x03 \x01(\x02\x12\x17\n\x0frmse_rotation_z\x18\x04 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.autoware_sensing_msgs.msg.gnss_ins_orientation_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GNSSINSORIENTATION']._serialized_start=207
  _globals['_GNSSINSORIENTATION']._serialized_end=383
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/map_msgs/srv/projected_maps_info.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.map_msgs.msg import projected_map_info_pb2 as make87__messages__ros2_dot_jazzy_dot_map__msgs_dot_msg_dot_projected__map__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/map_msgs/srv/projected_maps_info.proto\x12\'make87_messages_ros2.jazzy.map_msgs.srv\x1a@make87_messages_ros2/jazzy/map_msgs/msg/projected_map_info.proto\"r\n\x18ProjectedMapsInfoRequest\x12V\n\x13projected_maps_info\x18\x01 \x03(\x0b\x32\x39.make87_messages_ros2.jazzy.map_msgs.msg.ProjectedMapInfo\"\x1b\n\x19ProjectedMapsInfoResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.map_msgs.srv.projected_maps_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_PROJECTEDMAPSINFOREQUEST']._serialized_start=176
  _globals['_PROJECTEDMAPSINFOREQUEST']._serialized_end=290
  _globals['_PROJECTEDMAPSINFORESPONSE']._serialized_start=292
  _globals['_PROJECTEDMAPSINFORESPONSE']._serialized_end=319
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.rosbag2_test_msgdefs.msg import basic_msg_pb2 as _basic_msg_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ComplexSrvMsgRequest(_message.Message):
    __slots__ = ("req",)
    REQ_FIELD_NUMBER: _ClassVar[int]
    req: _basic_msg_pb2.BasicMsg
    def __init__(self, req: _Optional[_Union[_basic_msg_pb2.BasicMsg, _Mapping]] = ...) -> None: ...

class ComplexSrvMsgResponse(_message.Message):
    __slots__ = ("resp",)
    RESP_FIELD_NUMBER: _ClassVar[int]
    resp: _basic_msg_pb2.BasicMsg
    def __init__(self, resp: _Optional[_Union[_basic_msg_pb2.BasicMsg, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class StreamRateRequest(_message.Message):
    __slots__ = ("stream_id", "message_rate", "on_off")
    STREAM_ID_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_RATE_FIELD_NUMBER: _ClassVar[int]
    ON_OFF_FIELD_NUMBER: _ClassVar[int]
    stream_id: int
    message_rate: int
    on_off: bool
    def __init__(self, stream_id: _Optional[int] = ..., message_rate: _Optional[int] = ..., on_off: bool = ...) -> None: ...

class StreamRateResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PathPlanning(_message.Message):
    __slots__ = ("header", "ros2_header", "segment_type", "length", "start_speed", "end_speed", "startx", "starty", "endx", "endy", "theta0", "a1", "a2", "k0", "c1", "c2", "behavior", "creep", "acc", "reverse", "vehicle_track", "transmitted", "aux_transmitted", "theta_end", "k_end", "seg_len", "speed_limit", "max_error", "max_smooth", "max_curv", "possible_points", "exit_segment")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    SEGMENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    LENGTH_FIELD_NUMBER: _ClassVar[int]
    START_SPEED_FIELD_NUMBER: _ClassVar[int]
    END_SPEED_FIELD_NUMBER: _ClassVar[int]
    STARTX_FIELD_NUMBER: _ClassVar[int]
    STARTY_FIELD_NUMBER: _ClassVar[int]
    ENDX_FIELD_NUMBER: _ClassVar[int]
    ENDY_FIELD_NUMBER: _ClassVar[int]
    THETA0_FIELD_NUMBER: _ClassVar[int]
    A1_FIELD_NUMBER: _ClassVar[int]
    A2_FIELD_NUMBER: _ClassVar[int]
    K0_FIELD_NUMBER: _ClassVar[int]
    C1_FIELD_NUMBER: _ClassVar[int]
    C2_FIELD_NUMBER: _ClassVar[int]
    BEHAVIOR_FIELD_NUMBER: _ClassVar[int]
    CREEP_FIELD_NUMBER: _ClassVar[int]
    ACC_FIELD_NUMBER: _ClassVar[int]
    REVERSE_FIELD_NUMBER: _ClassVar[int]
    VEHICLE_TRACK_FIELD_NUMBER: _ClassVar[int]
    TRANSMITTED_FIELD_NUMBER: _ClassVar[int]
    AUX_TRANSMITTED_FIELD_NUMBER: _ClassVar[int]
    THETA_END_FIELD_NUMBER: _ClassVar[int]
    K_END_FIELD_NUMBER: _ClassVar[int]
    SEG_LEN_FIELD_NUMBER: _ClassVar[int]
    SPEED_LIMIT_FIELD_NUMBER: _ClassVar[int]
    MAX_ERROR_FIELD_NUMBER: _ClassVar[int]
    MAX_SMOOTH_FIELD_NUMBER: _ClassVar[int]
    MAX_CURV_FIELD_NUMBER: _ClassVar[int]
    POSSIBLE_POINTS_FIELD_NUMBER: _ClassVar[int]
    EXIT_SEGMENT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    segment_type: int
    length: float
    start_speed: float
    end_speed: float
    startx: float
    starty: float
    endx: float
    endy: float
    theta0: float
    a1: float
    a2: float
    k0: float
    c1: float
    c2: float
    behavior: int
    creep: int
    acc: int
    reverse: int
    vehicle_track: int
    transmitted: bool
    aux_transmitted: bool
    theta_end: float
    k_end: float
    seg_len: int
    speed_limit: float
    max_error: float
    max_smooth: float
    max_curv: float
    possible_points: int
    exit_segment: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., segment_type: _Optional[int] = ..., length: _Optional[float] = ..., start_speed: _Optional[float] = ..., end_speed: _Optional[float] = ..., startx: _Optional[float] = ..., starty: _Optional[float] = ..., endx: _Optional[float] = ..., endy: _Optional[float] = ..., theta0: _Optional[float] = ..., a1: _Optional[float] = ..., a2: _Optional[float] = ..., k0: _Optional[float] = ..., c1: _Optional[float] = ..., c2: _Optional[float] = ..., behavior: _Optional[int] = ..., creep: _Optional[int] = ..., acc: _Optional[int] = ..., reverse: _Optional[int] = ..., vehicle_track: _Optional[int] = ..., transmitted: bool = ..., aux_transmitted: bool = ..., theta_end: _Optional[float] = ..., k_end: _Optional[float] = ..., seg_len: _Optional[int] = ..., speed_limit: _Optional[float] = ..., max_error: _Optional[float] = ..., max_smooth: _Optional[float] = ..., max_curv: _Optional[float] = ..., possible_points: _Optional[int] = ..., exit_segment: bool = ...) -> None: ...



from make87_messages_ros2.rolling.moveit_msgs.msg import allowed_collision_entry_pb2 as _allowed_collision_entry_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AllowedCollisionMatrix(_message.Message):
    __slots__ = ("entry_names", "entry_values", "default_entry_names", "default_entry_values")
    ENTRY_NAMES_FIELD_NUMBER: _ClassVar[int]
    ENTRY_VALUES_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_ENTRY_NAMES_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_ENTRY_VALUES_FIELD_NUMBER: _ClassVar[int]
    entry_names: _containers.RepeatedScalarFieldContainer[str]
    entry_values: _containers.RepeatedCompositeFieldContainer[_allowed_collision_entry_pb2.AllowedCollisionEntry]
    default_entry_names: _containers.RepeatedScalarFieldContainer[str]
    default_entry_values: _containers.RepeatedScalarFieldContainer[bool]
    def __init__(self, entry_names: _Optional[_Iterable[str]] = ..., entry_values: _Optional[_Iterable[_Union[_allowed_collision_entry_pb2.AllowedCollisionEntry, _Mapping]]] = ..., default_entry_names: _Optional[_Iterable[str]] = ..., default_entry_values: _Optional[_Iterable[bool]] = ...) -> None: ...



from make87_messages_ros2.jazzy.cartographer_ros_msgs.msg import status_response_pb2 as _status_response_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class WriteStateRequest(_message.Message):
    __slots__ = ("filename", "include_unfinished_submaps")
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_UNFINISHED_SUBMAPS_FIELD_NUMBER: _ClassVar[int]
    filename: str
    include_unfinished_submaps: bool
    def __init__(self, filename: _Optional[str] = ..., include_unfinished_submaps: bool = ...) -> None: ...

class WriteStateResponse(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _status_response_pb2.StatusResponse
    def __init__(self, status: _Optional[_Union[_status_response_pb2.StatusResponse, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ibeo_msgs/msg/scan_data2204.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.ibeo_msgs.msg import ibeo_data_header_pb2 as make87__messages__ros2_dot_humble_dot_ibeo__msgs_dot_msg_dot_ibeo__data__header__pb2
from make87_messages_ros2.humble.ibeo_msgs.msg import scan_point2204_pb2 as make87__messages__ros2_dot_humble_dot_ibeo__msgs_dot_msg_dot_scan__point2204__pb2
from make87_messages_ros2.humble.ibeo_msgs.msg import scanner_info2204_pb2 as make87__messages__ros2_dot_humble_dot_ibeo__msgs_dot_msg_dot_scanner__info2204__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/humble/ibeo_msgs/msg/scan_data2204.proto\x12)make87_messages_ros2.humble.ibeo_msgs.msg\x1a!make87_messages/core/header.proto\x1a@make87_messages_ros2/humble/ibeo_msgs/msg/ibeo_data_header.proto\x1a>make87_messages_ros2/humble/ibeo_msgs/msg/scan_point2204.proto\x1a@make87_messages_ros2/humble/ibeo_msgs/msg/scanner_info2204.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\x87\x05\n\x0cScanData2204\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12N\n\x0bibeo_header\x18\x03 \x01(\x0b\x32\x39.make87_messages_ros2.humble.ibeo_msgs.msg.IbeoDataHeader\x12\x17\n\x0fscan_start_time\x18\x04 \x01(\x04\x12\x1c\n\x14scan_end_time_offset\x18\x05 \x01(\r\x12\x16\n\x0eground_labeled\x18\x06 \x01(\x08\x12\x14\n\x0c\x64irt_labeled\x18\x07 \x01(\x08\x12\x14\n\x0crain_labeled\x18\x08 \x01(\x08\x12\x12\n\nfused_scan\x18\t \x01(\x08\x12\x13\n\x0bmirror_side\x18\n \x01(\r\x12\x19\n\x11\x63oordinate_system\x18\x0b \x01(\r\x12\x13\n\x0bscan_number\x18\x0c \x01(\r\x12\x13\n\x0bscan_points\x18\r \x01(\r\x12\x1f\n\x17number_of_scanner_infos\x18\x0e \x01(\r\x12U\n\x11scanner_info_list\x18\x0f \x03(\x0b\x32:.make87_messages_ros2.humble.ibeo_msgs.msg.ScannerInfo2204\x12Q\n\x0fscan_point_list\x18\x10 \x03(\x0b\x32\x38.make87_messages_ros2.humble.ibeo_msgs.msg.ScanPoint2204b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ibeo_msgs.msg.scan_data2204_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SCANDATA2204']._serialized_start=395
  _globals['_SCANDATA2204']._serialized_end=1042
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.sensor_msgs.msg import point_cloud2_pb2 as _point_cloud2_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetPointMapRequest(_message.Message):
    __slots__ = ("header",)
    HEADER_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ...) -> None: ...

class GetPointMapResponse(_message.Message):
    __slots__ = ("header", "map")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MAP_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    map: _point_cloud2_pb2.PointCloud2
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., map: _Optional[_Union[_point_cloud2_pb2.PointCloud2, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rtabmap_msgs/srv/get_node_data.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.rtabmap_msgs.msg import node_pb2 as make87__messages__ros2_dot_humble_dot_rtabmap__msgs_dot_msg_dot_node__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/humble/rtabmap_msgs/srv/get_node_data.proto\x12,make87_messages_ros2.humble.rtabmap_msgs.srv\x1a!make87_messages/core/header.proto\x1a\x37make87_messages_ros2/humble/rtabmap_msgs/msg/node.proto\"\x8e\x01\n\x12GetNodeDataRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0b\n\x03ids\x18\x02 \x03(\x05\x12\x0e\n\x06images\x18\x03 \x01(\x08\x12\x0c\n\x04scan\x18\x04 \x01(\x08\x12\x0c\n\x04grid\x18\x05 \x01(\x08\x12\x11\n\tuser_data\x18\x06 \x01(\x08\"\x85\x01\n\x13GetNodeDataResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12@\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x32.make87_messages_ros2.humble.rtabmap_msgs.msg.Nodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rtabmap_msgs.srv.get_node_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETNODEDATAREQUEST']._serialized_start=207
  _globals['_GETNODEDATAREQUEST']._serialized_end=349
  _globals['_GETNODEDATARESPONSE']._serialized_start=352
  _globals['_GETNODEDATARESPONSE']._serialized_end=485
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PointCloudMapCellMetaData(_message.Message):
    __slots__ = ("header", "min_x", "min_y", "max_x", "max_y")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MIN_X_FIELD_NUMBER: _ClassVar[int]
    MIN_Y_FIELD_NUMBER: _ClassVar[int]
    MAX_X_FIELD_NUMBER: _ClassVar[int]
    MAX_Y_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    min_x: float
    min_y: float
    max_x: float
    max_y: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., min_x: _Optional[float] = ..., min_y: _Optional[float] = ..., max_x: _Optional[float] = ..., max_y: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SrrStatus1(_message.Message):
    __slots__ = ("header", "can_tx_look_type", "can_tx_dsp_timestamp", "can_tx_yaw_rate_calc", "can_tx_vehicle_speed_calc", "can_tx_scan_index", "can_tx_curvature")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_LOOK_TYPE_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_DSP_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_YAW_RATE_CALC_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_VEHICLE_SPEED_CALC_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_SCAN_INDEX_FIELD_NUMBER: _ClassVar[int]
    CAN_TX_CURVATURE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    can_tx_look_type: bool
    can_tx_dsp_timestamp: int
    can_tx_yaw_rate_calc: float
    can_tx_vehicle_speed_calc: float
    can_tx_scan_index: int
    can_tx_curvature: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., can_tx_look_type: bool = ..., can_tx_dsp_timestamp: _Optional[int] = ..., can_tx_yaw_rate_calc: _Optional[float] = ..., can_tx_vehicle_speed_calc: _Optional[float] = ..., can_tx_scan_index: _Optional[int] = ..., can_tx_curvature: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import float64_pb2 as _float64_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TestNestedServiceRequest(_message.Message):
    __slots__ = ("pose",)
    POSE_FIELD_NUMBER: _ClassVar[int]
    pose: _pose_pb2.Pose
    def __init__(self, pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ...) -> None: ...

class TestNestedServiceResponse(_message.Message):
    __slots__ = ("data",)
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: _float64_pb2.Float64
    def __init__(self, data: _Optional[_Union[_float64_pb2.Float64, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from make87_messages_ros2.rolling.ublox_ubx_msgs.msg import sbas_service_pb2 as _sbas_service_pb2
from make87_messages_ros2.rolling.ublox_ubx_msgs.msg import sbas_status_flags_pb2 as _sbas_status_flags_pb2
from make87_messages_ros2.rolling.ublox_ubx_msgs.msg import sbas_sv_data_pb2 as _sbas_sv_data_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UBXNavSBAS(_message.Message):
    __slots__ = ("header", "itow", "geo", "mode", "sys", "service", "cnt", "status_flags", "reserved_0", "sv_data")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ITOW_FIELD_NUMBER: _ClassVar[int]
    GEO_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    SYS_FIELD_NUMBER: _ClassVar[int]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    CNT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FLAGS_FIELD_NUMBER: _ClassVar[int]
    RESERVED_0_FIELD_NUMBER: _ClassVar[int]
    SV_DATA_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    itow: int
    geo: int
    mode: int
    sys: int
    service: _sbas_service_pb2.SBASService
    cnt: int
    status_flags: _sbas_status_flags_pb2.SBASStatusFlags
    reserved_0: _containers.RepeatedScalarFieldContainer[int]
    sv_data: _containers.RepeatedCompositeFieldContainer[_sbas_sv_data_pb2.SBASSvData]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., itow: _Optional[int] = ..., geo: _Optional[int] = ..., mode: _Optional[int] = ..., sys: _Optional[int] = ..., service: _Optional[_Union[_sbas_service_pb2.SBASService, _Mapping]] = ..., cnt: _Optional[int] = ..., status_flags: _Optional[_Union[_sbas_status_flags_pb2.SBASStatusFlags, _Mapping]] = ..., reserved_0: _Optional[_Iterable[int]] = ..., sv_data: _Optional[_Iterable[_Union[_sbas_sv_data_pb2.SBASSvData, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ObstacleData(_message.Message):
    __slots__ = ("header", "obstacle_id", "obstacle_pos_x", "obstacle_pos_y", "blinker_info", "cut_in_and_out", "obstacle_rel_vel_x", "obstacle_type", "obstacle_status", "obstacle_brake_lights", "obstacle_valid", "obstacle_length", "obstacle_width", "obstacle_age", "obstacle_lane", "cipv_flag", "radar_pos_x", "radar_vel_x", "radar_match_confidence", "matched_radar_id", "obstacle_angle_rate", "obstacle_scale_change", "object_accel_x", "obstacle_replaced", "obstacle_angle")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    OBSTACLE_ID_FIELD_NUMBER: _ClassVar[int]
    OBSTACLE_POS_X_FIELD_NUMBER: _ClassVar[int]
    OBSTACLE_POS_Y_FIELD_NUMBER: _ClassVar[int]
    BLINKER_INFO_FIELD_NUMBER: _ClassVar[int]
    CUT_IN_AND_OUT_FIELD_NUMBER: _ClassVar[int]
    OBSTACLE_REL_VEL_X_FIELD_NUMBER: _ClassVar[int]
    OBSTACLE_TYPE_FIELD_NUMBER: _ClassVar[int]
    OBSTACLE_STATUS_FIELD_NUMBER: _ClassVar[int]
    OBSTACLE_BRAKE_LIGHTS_FIELD_NUMBER: _ClassVar[int]
    OBSTACLE_VALID_FIELD_NUMBER: _ClassVar[int]
    OBSTACLE_LENGTH_FIELD_NUMBER: _ClassVar[int]
    OBSTACLE_WIDTH_FIELD_NUMBER: _ClassVar[int]
    OBSTACLE_AGE_FIELD_NUMBER: _ClassVar[int]
    OBSTACLE_LANE_FIELD_NUMBER: _ClassVar[int]
    CIPV_FLAG_FIELD_NUMBER: _ClassVar[int]
    RADAR_POS_X_FIELD_NUMBER: _ClassVar[int]
    RADAR_VEL_X_FIELD_NUMBER: _ClassVar[int]
    RADAR_MATCH_CONFIDENCE_FIELD_NUMBER: _ClassVar[int]
    MATCHED_RADAR_ID_FIELD_NUMBER: _ClassVar[int]
    OBSTACLE_ANGLE_RATE_FIELD_NUMBER: _ClassVar[int]
    OBSTACLE_SCALE_CHANGE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ACCEL_X_FIELD_NUMBER: _ClassVar[int]
    OBSTACLE_REPLACED_FIELD_NUMBER: _ClassVar[int]
    OBSTACLE_ANGLE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    obstacle_id: int
    obstacle_pos_x: float
    obstacle_pos_y: float
    blinker_info: int
    cut_in_and_out: int
    obstacle_rel_vel_x: float
    obstacle_type: int
    obstacle_status: int
    obstacle_brake_lights: bool
    obstacle_valid: int
    obstacle_length: float
    obstacle_width: float
    obstacle_age: int
    obstacle_lane: int
    cipv_flag: bool
    radar_pos_x: float
    radar_vel_x: float
    radar_match_confidence: int
    matched_radar_id: int
    obstacle_angle_rate: float
    obstacle_scale_change: float
    object_accel_x: float
    obstacle_replaced: bool
    obstacle_angle: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., obstacle_id: _Optional[int] = ..., obstacle_pos_x: _Optional[float] = ..., obstacle_pos_y: _Optional[float] = ..., blinker_info: _Optional[int] = ..., cut_in_and_out: _Optional[int] = ..., obstacle_rel_vel_x: _Optional[float] = ..., obstacle_type: _Optional[int] = ..., obstacle_status: _Optional[int] = ..., obstacle_brake_lights: bool = ..., obstacle_valid: _Optional[int] = ..., obstacle_length: _Optional[float] = ..., obstacle_width: _Optional[float] = ..., obstacle_age: _Optional[int] = ..., obstacle_lane: _Optional[int] = ..., cipv_flag: bool = ..., radar_pos_x: _Optional[float] = ..., radar_vel_x: _Optional[float] = ..., radar_match_confidence: _Optional[int] = ..., matched_radar_id: _Optional[int] = ..., obstacle_angle_rate: _Optional[float] = ..., obstacle_scale_change: _Optional[float] = ..., object_accel_x: _Optional[float] = ..., obstacle_replaced: bool = ..., obstacle_angle: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_task_msgs/msg/task_description.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.rolling.rmf_task_msgs.msg import clean_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__task__msgs_dot_msg_dot_clean__pb2
from make87_messages_ros2.rolling.rmf_task_msgs.msg import delivery_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__task__msgs_dot_msg_dot_delivery__pb2
from make87_messages_ros2.rolling.rmf_task_msgs.msg import loop_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__task__msgs_dot_msg_dot_loop__pb2
from make87_messages_ros2.rolling.rmf_task_msgs.msg import priority_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__task__msgs_dot_msg_dot_priority__pb2
from make87_messages_ros2.rolling.rmf_task_msgs.msg import station_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__task__msgs_dot_msg_dot_station__pb2
from make87_messages_ros2.rolling.rmf_task_msgs.msg import task_type_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__task__msgs_dot_msg_dot_task__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/rmf_task_msgs/msg/task_description.proto\x12.make87_messages_ros2.rolling.rmf_task_msgs.msg\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\x1a:make87_messages_ros2/rolling/rmf_task_msgs/msg/clean.proto\x1a=make87_messages_ros2/rolling/rmf_task_msgs/msg/delivery.proto\x1a\x39make87_messages_ros2/rolling/rmf_task_msgs/msg/loop.proto\x1a=make87_messages_ros2/rolling/rmf_task_msgs/msg/priority.proto\x1a<make87_messages_ros2/rolling/rmf_task_msgs/msg/station.proto\x1a>make87_messages_ros2/rolling/rmf_task_msgs/msg/task_type.proto\"\x99\x04\n\x0fTaskDescription\x12M\n\nstart_time\x18\x01 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12J\n\x08priority\x18\x02 \x01(\x0b\x32\x38.make87_messages_ros2.rolling.rmf_task_msgs.msg.Priority\x12K\n\ttask_type\x18\x03 \x01(\x0b\x32\x38.make87_messages_ros2.rolling.rmf_task_msgs.msg.TaskType\x12H\n\x07station\x18\x04 \x01(\x0b\x32\x37.make87_messages_ros2.rolling.rmf_task_msgs.msg.Station\x12\x42\n\x04loop\x18\x05 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.rmf_task_msgs.msg.Loop\x12J\n\x08\x64\x65livery\x18\x06 \x01(\x0b\x32\x38.make87_messages_ros2.rolling.rmf_task_msgs.msg.Delivery\x12\x44\n\x05\x63lean\x18\x07 \x01(\x0b\x32\x35.make87_messages_ros2.rolling.rmf_task_msgs.msg.Cleanb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_task_msgs.msg.task_description_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TASKDESCRIPTION']._serialized_start=557
  _globals['_TASKDESCRIPTION']._serialized_end=1094
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/nao_command_msgs/msg/chest_led.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.std_msgs.msg import color_rgba_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_color__rgba__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/humble/nao_command_msgs/msg/chest_led.proto\x12\x30make87_messages_ros2.humble.nao_command_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x39make87_messages_ros2/humble/std_msgs/msg/color_rgba.proto\"|\n\x08\x43hestLed\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x42\n\x05\x63olor\x18\x02 \x01(\x0b\x32\x33.make87_messages_ros2.humble.std_msgs.msg.ColorRGBAb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.nao_command_msgs.msg.chest_led_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CHESTLED']._serialized_start=212
  _globals['_CHESTLED']._serialized_end=336
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/autoware_perception_msgs/msg/object_classification.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nUmake87_messages_ros2/rolling/autoware_perception_msgs/msg/object_classification.proto\x12\x39make87_messages_ros2.rolling.autoware_perception_msgs.msg\":\n\x14ObjectClassification\x12\r\n\x05label\x18\x01 \x01(\r\x12\x13\n\x0bprobability\x18\x02 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.autoware_perception_msgs.msg.object_classification_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_OBJECTCLASSIFICATION']._serialized_start=148
  _globals['_OBJECTCLASSIFICATION']._serialized_end=206
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/delphi_esr_msgs/msg/esr_vehicle5.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/rolling/delphi_esr_msgs/msg/esr_vehicle5.proto\x12\x30make87_messages_ros2.rolling.delphi_esr_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xc7\x02\n\x0b\x45srVehicle5\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x1c\n\x14oversteer_understeer\x18\x02 \x01(\x05\x12\x1b\n\x13yaw_rate_bias_shift\x18\x03 \x01(\x08\x12\x16\n\x0e\x62\x65\x61mwidth_vert\x18\x04 \x01(\x02\x12\x1a\n\x12\x66unnel_offset_left\x18\x05 \x01(\x02\x12\x1b\n\x13\x66unnel_offset_right\x18\x06 \x01(\x02\x12\x1d\n\x15\x63w_blockage_threshold\x18\x07 \x01(\x02\x12\x1a\n\x12\x64istance_rear_axle\x18\x08 \x01(\r\x12\x11\n\twheelbase\x18\t \x01(\r\x12\x1b\n\x13steering_gear_ratio\x18\n \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.delphi_esr_msgs.msg.esr_vehicle5_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ESRVEHICLE5']._serialized_start=178
  _globals['_ESRVEHICLE5']._serialized_end=505
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ros_gz_interfaces/msg/light.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_vector3__pb2
from make87_messages_ros2.humble.std_msgs.msg import color_rgba_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_color__rgba__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/humble/ros_gz_interfaces/msg/light.proto\x12\x31make87_messages_ros2.humble.ros_gz_interfaces.msg\x1a!make87_messages/core/header.proto\x1a\x38make87_messages_ros2/humble/geometry_msgs/msg/pose.proto\x1a;make87_messages_ros2/humble/geometry_msgs/msg/vector3.proto\x1a\x39make87_messages_ros2/humble/std_msgs/msg/color_rgba.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xad\x05\n\x05Light\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\r\x12\x41\n\x04pose\x18\x05 \x01(\x0b\x32\x33.make87_messages_ros2.humble.geometry_msgs.msg.Pose\x12\x44\n\x07\x64iffuse\x18\x06 \x01(\x0b\x32\x33.make87_messages_ros2.humble.std_msgs.msg.ColorRGBA\x12\x45\n\x08specular\x18\x07 \x01(\x0b\x32\x33.make87_messages_ros2.humble.std_msgs.msg.ColorRGBA\x12\x1c\n\x14\x61ttenuation_constant\x18\x08 \x01(\x02\x12\x1a\n\x12\x61ttenuation_linear\x18\t \x01(\x02\x12\x1d\n\x15\x61ttenuation_quadratic\x18\n \x01(\x02\x12I\n\tdirection\x18\x0b \x01(\x0b\x32\x36.make87_messages_ros2.humble.geometry_msgs.msg.Vector3\x12\r\n\x05range\x18\x0c \x01(\x02\x12\x14\n\x0c\x63\x61st_shadows\x18\r \x01(\x08\x12\x18\n\x10spot_inner_angle\x18\x0e \x01(\x02\x12\x18\n\x10spot_outer_angle\x18\x0f \x01(\x02\x12\x14\n\x0cspot_falloff\x18\x10 \x01(\x02\x12\n\n\x02id\x18\x11 \x01(\r\x12\x11\n\tparent_id\x18\x12 \x01(\r\x12\x11\n\tintensity\x18\x13 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ros_gz_interfaces.msg.light_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LIGHT']._serialized_start=385
  _globals['_LIGHT']._serialized_end=1070
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/sick_scan_xd/srv/field_set_read_srv.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/jazzy/sick_scan_xd/srv/field_set_read_srv.proto\x12+make87_messages_ros2.jazzy.sick_scan_xd.srv\"\x18\n\x16\x46ieldSetReadSrvRequest\"h\n\x17\x46ieldSetReadSrvResponse\x12\"\n\x1a\x66ield_set_selection_method\x18\x01 \x01(\x05\x12\x18\n\x10\x61\x63tive_field_set\x18\x02 \x01(\x05\x12\x0f\n\x07success\x18\x03 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.sick_scan_xd.srv.field_set_read_srv_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_FIELDSETREADSRVREQUEST']._serialized_start=117
  _globals['_FIELDSETREADSRVREQUEST']._serialized_end=141
  _globals['_FIELDSETREADSRVRESPONSE']._serialized_start=143
  _globals['_FIELDSETREADSRVRESPONSE']._serialized_end=247
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UserLed(_message.Message):
    __slots__ = ("header", "led", "color", "blink_period", "duty_cycle")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    LED_FIELD_NUMBER: _ClassVar[int]
    COLOR_FIELD_NUMBER: _ClassVar[int]
    BLINK_PERIOD_FIELD_NUMBER: _ClassVar[int]
    DUTY_CYCLE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    led: int
    color: int
    blink_period: int
    duty_cycle: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., led: _Optional[int] = ..., color: _Optional[int] = ..., blink_period: _Optional[int] = ..., duty_cycle: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/moveit_msgs/srv/apply_planning_scene.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.moveit_msgs.msg import planning_scene_pb2 as make87__messages__ros2_dot_humble_dot_moveit__msgs_dot_msg_dot_planning__scene__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/humble/moveit_msgs/srv/apply_planning_scene.proto\x12+make87_messages_ros2.humble.moveit_msgs.srv\x1a!make87_messages/core/header.proto\x1a@make87_messages_ros2/humble/moveit_msgs/msg/planning_scene.proto\"\x94\x01\n\x19\x41pplyPlanningSceneRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12I\n\x05scene\x18\x02 \x01(\x0b\x32:.make87_messages_ros2.humble.moveit_msgs.msg.PlanningScene\"[\n\x1a\x41pplyPlanningSceneResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.moveit_msgs.srv.apply_planning_scene_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_APPLYPLANNINGSCENEREQUEST']._serialized_start=221
  _globals['_APPLYPLANNINGSCENEREQUEST']._serialized_end=369
  _globals['_APPLYPLANNINGSCENERESPONSE']._serialized_start=371
  _globals['_APPLYPLANNINGSCENERESPONSE']._serialized_end=462
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetMeasurementsRequest(_message.Message):
    __slots__ = ("header", "id", "max_repeats", "get_positions", "get_currents", "get_commands")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    MAX_REPEATS_FIELD_NUMBER: _ClassVar[int]
    GET_POSITIONS_FIELD_NUMBER: _ClassVar[int]
    GET_CURRENTS_FIELD_NUMBER: _ClassVar[int]
    GET_COMMANDS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    id: int
    max_repeats: int
    get_positions: bool
    get_currents: bool
    get_commands: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., id: _Optional[int] = ..., max_repeats: _Optional[int] = ..., get_positions: bool = ..., get_currents: bool = ..., get_commands: bool = ...) -> None: ...

class GetMeasurementsResponse(_message.Message):
    __slots__ = ("header", "success", "failures", "positions", "currents", "commands", "stamp")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    FAILURES_FIELD_NUMBER: _ClassVar[int]
    POSITIONS_FIELD_NUMBER: _ClassVar[int]
    CURRENTS_FIELD_NUMBER: _ClassVar[int]
    COMMANDS_FIELD_NUMBER: _ClassVar[int]
    STAMP_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    failures: int
    positions: _containers.RepeatedScalarFieldContainer[int]
    currents: _containers.RepeatedScalarFieldContainer[int]
    commands: _containers.RepeatedScalarFieldContainer[int]
    stamp: _time_pb2.Time
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ..., failures: _Optional[int] = ..., positions: _Optional[_Iterable[int]] = ..., currents: _Optional[_Iterable[int]] = ..., commands: _Optional[_Iterable[int]] = ..., stamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.off_highway_premium_radar_sample_msgs.msg import sensor_broadcast_data_pb2 as _sensor_broadcast_data_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SensorBroadcast(_message.Message):
    __slots__ = ("header", "ros2_header", "lgp_version", "sensor_broadcast_data")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    LGP_VERSION_FIELD_NUMBER: _ClassVar[int]
    SENSOR_BROADCAST_DATA_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    lgp_version: int
    sensor_broadcast_data: _sensor_broadcast_data_pb2.SensorBroadcastData
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., lgp_version: _Optional[int] = ..., sensor_broadcast_data: _Optional[_Union[_sensor_broadcast_data_pb2.SensorBroadcastData, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_task_msgs/msg/delivery.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_dispenser_msgs.msg import dispenser_request_item_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__dispenser__msgs_dot_msg_dot_dispenser__request__item__pb2
from make87_messages_ros2.rolling.rmf_task_msgs.msg import behavior_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__task__msgs_dot_msg_dot_behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/rolling/rmf_task_msgs/msg/delivery.proto\x12.make87_messages_ros2.rolling.rmf_task_msgs.msg\x1aPmake87_messages_ros2/rolling/rmf_dispenser_msgs/msg/dispenser_request_item.proto\x1a=make87_messages_ros2/rolling/rmf_task_msgs/msg/behavior.proto\"\x87\x03\n\x08\x44\x65livery\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12X\n\x05items\x18\x02 \x03(\x0b\x32I.make87_messages_ros2.rolling.rmf_dispenser_msgs.msg.DispenserRequestItem\x12\x19\n\x11pickup_place_name\x18\x03 \x01(\t\x12\x18\n\x10pickup_dispenser\x18\x04 \x01(\t\x12Q\n\x0fpickup_behavior\x18\x05 \x01(\x0b\x32\x38.make87_messages_ros2.rolling.rmf_task_msgs.msg.Behavior\x12\x1a\n\x12\x64ropoff_place_name\x18\x06 \x01(\t\x12\x18\n\x10\x64ropoff_ingestor\x18\x07 \x01(\t\x12R\n\x10\x64ropoff_behavior\x18\x08 \x01(\x0b\x32\x38.make87_messages_ros2.rolling.rmf_task_msgs.msg.Behaviorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_task_msgs.msg.delivery_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DELIVERY']._serialized_start=259
  _globals['_DELIVERY']._serialized_end=650
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class FileWriteRequest(_message.Message):
    __slots__ = ("file_path", "offset", "data")
    FILE_PATH_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    file_path: str
    offset: int
    data: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, file_path: _Optional[str] = ..., offset: _Optional[int] = ..., data: _Optional[_Iterable[int]] = ...) -> None: ...

class FileWriteResponse(_message.Message):
    __slots__ = ("success", "r_errno")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    R_ERRNO_FIELD_NUMBER: _ClassVar[int]
    success: bool
    r_errno: int
    def __init__(self, success: bool = ..., r_errno: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/autoware_perception_msgs/msg/tracked_object.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.autoware_perception_msgs.msg import object_classification_pb2 as make87__messages__ros2_dot_rolling_dot_autoware__perception__msgs_dot_msg_dot_object__classification__pb2
from make87_messages_ros2.rolling.autoware_perception_msgs.msg import shape_pb2 as make87__messages__ros2_dot_rolling_dot_autoware__perception__msgs_dot_msg_dot_shape__pb2
from make87_messages_ros2.rolling.autoware_perception_msgs.msg import tracked_object_kinematics_pb2 as make87__messages__ros2_dot_rolling_dot_autoware__perception__msgs_dot_msg_dot_tracked__object__kinematics__pb2
from make87_messages_ros2.rolling.unique_identifier_msgs.msg import uuid_pb2 as make87__messages__ros2_dot_rolling_dot_unique__identifier__msgs_dot_msg_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNmake87_messages_ros2/rolling/autoware_perception_msgs/msg/tracked_object.proto\x12\x39make87_messages_ros2.rolling.autoware_perception_msgs.msg\x1aUmake87_messages_ros2/rolling/autoware_perception_msgs/msg/object_classification.proto\x1a\x45make87_messages_ros2/rolling/autoware_perception_msgs/msg/shape.proto\x1aYmake87_messages_ros2/rolling/autoware_perception_msgs/msg/tracked_object_kinematics.proto\x1a\x42make87_messages_ros2/rolling/unique_identifier_msgs/msg/uuid.proto\"\xa2\x03\n\rTrackedObject\x12P\n\tobject_id\x18\x01 \x01(\x0b\x32=.make87_messages_ros2.rolling.unique_identifier_msgs.msg.UUID\x12\x1d\n\x15\x65xistence_probability\x18\x02 \x01(\x02\x12g\n\x0e\x63lassification\x18\x03 \x03(\x0b\x32O.make87_messages_ros2.rolling.autoware_perception_msgs.msg.ObjectClassification\x12\x66\n\nkinematics\x18\x04 \x01(\x0b\x32R.make87_messages_ros2.rolling.autoware_perception_msgs.msg.TrackedObjectKinematics\x12O\n\x05shape\x18\x05 \x01(\x0b\x32@.make87_messages_ros2.rolling.autoware_perception_msgs.msg.Shapeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.autoware_perception_msgs.msg.tracked_object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TRACKEDOBJECT']._serialized_start=459
  _globals['_TRACKEDOBJECT']._serialized_end=877
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Information(_message.Message):
    __slots__ = ("header", "ros2_header", "number_sensors", "sending_pattern", "operating_mode", "outside_temperature", "sensor_blindness", "sensitivity", "sensor_faulted", "failure_status")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    NUMBER_SENSORS_FIELD_NUMBER: _ClassVar[int]
    SENDING_PATTERN_FIELD_NUMBER: _ClassVar[int]
    OPERATING_MODE_FIELD_NUMBER: _ClassVar[int]
    OUTSIDE_TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    SENSOR_BLINDNESS_FIELD_NUMBER: _ClassVar[int]
    SENSITIVITY_FIELD_NUMBER: _ClassVar[int]
    SENSOR_FAULTED_FIELD_NUMBER: _ClassVar[int]
    FAILURE_STATUS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    number_sensors: int
    sending_pattern: int
    operating_mode: int
    outside_temperature: float
    sensor_blindness: int
    sensitivity: int
    sensor_faulted: int
    failure_status: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., number_sensors: _Optional[int] = ..., sending_pattern: _Optional[int] = ..., operating_mode: _Optional[int] = ..., outside_temperature: _Optional[float] = ..., sensor_blindness: _Optional[int] = ..., sensitivity: _Optional[int] = ..., sensor_faulted: _Optional[int] = ..., failure_status: bool = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.jazzy.sbg_driver.msg import sbg_imu_status_pb2 as _sbg_imu_status_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SbgImuData(_message.Message):
    __slots__ = ("header", "time_stamp", "imu_status", "accel", "gyro", "temp", "delta_vel", "delta_angle")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TIME_STAMP_FIELD_NUMBER: _ClassVar[int]
    IMU_STATUS_FIELD_NUMBER: _ClassVar[int]
    ACCEL_FIELD_NUMBER: _ClassVar[int]
    GYRO_FIELD_NUMBER: _ClassVar[int]
    TEMP_FIELD_NUMBER: _ClassVar[int]
    DELTA_VEL_FIELD_NUMBER: _ClassVar[int]
    DELTA_ANGLE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    time_stamp: int
    imu_status: _sbg_imu_status_pb2.SbgImuStatus
    accel: _vector3_pb2.Vector3
    gyro: _vector3_pb2.Vector3
    temp: float
    delta_vel: _vector3_pb2.Vector3
    delta_angle: _vector3_pb2.Vector3
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., time_stamp: _Optional[int] = ..., imu_status: _Optional[_Union[_sbg_imu_status_pb2.SbgImuStatus, _Mapping]] = ..., accel: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., gyro: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., temp: _Optional[float] = ..., delta_vel: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., delta_angle: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_msgs/msg/cfg_rate.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages_ros2/jazzy/ublox_msgs/msg/cfg_rate.proto\x12)make87_messages_ros2.jazzy.ublox_msgs.msg\"@\n\x07\x43\x66gRATE\x12\x11\n\tmeas_rate\x18\x01 \x01(\r\x12\x10\n\x08nav_rate\x18\x02 \x01(\r\x12\x10\n\x08time_ref\x18\x03 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_msgs.msg.cfg_rate_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CFGRATE']._serialized_start=103
  _globals['_CFGRATE']._serialized_end=167
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/webots_ros2_msgs/msg/camera_recognition_object.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_stamped_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__stamped__pb2
from make87_messages_ros2.humble.std_msgs.msg import color_rgba_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_color__rgba__pb2
from make87_messages_ros2.humble.vision_msgs.msg import bounding_box2_d_pb2 as make87__messages__ros2_dot_humble_dot_vision__msgs_dot_msg_dot_bounding__box2__d__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPmake87_messages_ros2/humble/webots_ros2_msgs/msg/camera_recognition_object.proto\x12\x30make87_messages_ros2.humble.webots_ros2_msgs.msg\x1a!make87_messages/core/header.proto\x1a@make87_messages_ros2/humble/geometry_msgs/msg/pose_stamped.proto\x1a\x39make87_messages_ros2/humble/std_msgs/msg/color_rgba.proto\x1a\x41make87_messages_ros2/humble/vision_msgs/msg/bounding_box2_d.proto\"\xbb\x02\n\x17\x43\x61meraRecognitionObject\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\n\n\x02id\x18\x02 \x01(\x05\x12H\n\x04pose\x18\x03 \x01(\x0b\x32:.make87_messages_ros2.humble.geometry_msgs.msg.PoseStamped\x12H\n\x04\x62\x62ox\x18\x04 \x01(\x0b\x32:.make87_messages_ros2.humble.vision_msgs.msg.BoundingBox2D\x12\x43\n\x06\x63olors\x18\x05 \x03(\x0b\x32\x33.make87_messages_ros2.humble.std_msgs.msg.ColorRGBA\x12\r\n\x05model\x18\x06 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.webots_ros2_msgs.msg.camera_recognition_object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CAMERARECOGNITIONOBJECT']._serialized_start=362
  _globals['_CAMERARECOGNITIONOBJECT']._serialized_end=677
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class COData(_message.Message):
    __slots__ = ("index", "subindex", "data")
    INDEX_FIELD_NUMBER: _ClassVar[int]
    SUBINDEX_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    index: int
    subindex: int
    data: int
    def __init__(self, index: _Optional[int] = ..., subindex: _Optional[int] = ..., data: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MrrStatusRadar(_message.Message):
    __slots__ = ("header", "can_interference_type", "can_recommend_unconverge", "can_blockage_sidelobe_filter_val", "can_radar_align_incomplete", "can_blockage_sidelobe", "can_blockage_mnr", "can_radar_ext_cond_nok", "can_radar_align_out_range", "can_radar_align_not_start", "can_radar_overheat_error", "can_radar_not_op", "can_xcvr_operational")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CAN_INTERFERENCE_TYPE_FIELD_NUMBER: _ClassVar[int]
    CAN_RECOMMEND_UNCONVERGE_FIELD_NUMBER: _ClassVar[int]
    CAN_BLOCKAGE_SIDELOBE_FILTER_VAL_FIELD_NUMBER: _ClassVar[int]
    CAN_RADAR_ALIGN_INCOMPLETE_FIELD_NUMBER: _ClassVar[int]
    CAN_BLOCKAGE_SIDELOBE_FIELD_NUMBER: _ClassVar[int]
    CAN_BLOCKAGE_MNR_FIELD_NUMBER: _ClassVar[int]
    CAN_RADAR_EXT_COND_NOK_FIELD_NUMBER: _ClassVar[int]
    CAN_RADAR_ALIGN_OUT_RANGE_FIELD_NUMBER: _ClassVar[int]
    CAN_RADAR_ALIGN_NOT_START_FIELD_NUMBER: _ClassVar[int]
    CAN_RADAR_OVERHEAT_ERROR_FIELD_NUMBER: _ClassVar[int]
    CAN_RADAR_NOT_OP_FIELD_NUMBER: _ClassVar[int]
    CAN_XCVR_OPERATIONAL_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    can_interference_type: int
    can_recommend_unconverge: bool
    can_blockage_sidelobe_filter_val: int
    can_radar_align_incomplete: bool
    can_blockage_sidelobe: bool
    can_blockage_mnr: bool
    can_radar_ext_cond_nok: bool
    can_radar_align_out_range: bool
    can_radar_align_not_start: bool
    can_radar_overheat_error: bool
    can_radar_not_op: bool
    can_xcvr_operational: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., can_interference_type: _Optional[int] = ..., can_recommend_unconverge: bool = ..., can_blockage_sidelobe_filter_val: _Optional[int] = ..., can_radar_align_incomplete: bool = ..., can_blockage_sidelobe: bool = ..., can_blockage_mnr: bool = ..., can_radar_ext_cond_nok: bool = ..., can_radar_align_out_range: bool = ..., can_radar_align_not_start: bool = ..., can_radar_overheat_error: bool = ..., can_radar_not_op: bool = ..., can_xcvr_operational: bool = ...) -> None: ...



from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.rolling.marti_nav_msgs.msg import route_pb2 as _route_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PlanRouteRequest(_message.Message):
    __slots__ = ("header", "waypoints", "plan_from_vehicle")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    WAYPOINTS_FIELD_NUMBER: _ClassVar[int]
    PLAN_FROM_VEHICLE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    waypoints: _containers.RepeatedCompositeFieldContainer[_pose_pb2.Pose]
    plan_from_vehicle: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., waypoints: _Optional[_Iterable[_Union[_pose_pb2.Pose, _Mapping]]] = ..., plan_from_vehicle: bool = ...) -> None: ...

class PlanRouteResponse(_message.Message):
    __slots__ = ("route", "success", "message", "cost")
    ROUTE_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    COST_FIELD_NUMBER: _ClassVar[int]
    route: _route_pb2.Route
    success: bool
    message: str
    cost: float
    def __init__(self, route: _Optional[_Union[_route_pb2.Route, _Mapping]] = ..., success: bool = ..., message: _Optional[str] = ..., cost: _Optional[float] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class WaypointPullRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class WaypointPullResponse(_message.Message):
    __slots__ = ("success", "wp_received")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    WP_RECEIVED_FIELD_NUMBER: _ClassVar[int]
    success: bool
    wp_received: int
    def __init__(self, success: bool = ..., wp_received: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rcl_interfaces/srv/list_parameters.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rcl_interfaces.msg import list_parameters_result_pb2 as make87__messages__ros2_dot_rolling_dot_rcl__interfaces_dot_msg_dot_list__parameters__result__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/rcl_interfaces/srv/list_parameters.proto\x12/make87_messages_ros2.rolling.rcl_interfaces.srv\x1aLmake87_messages_ros2/rolling/rcl_interfaces/msg/list_parameters_result.proto\"8\n\x15ListParametersRequest\x12\x10\n\x08prefixes\x18\x01 \x03(\t\x12\r\n\x05\x64\x65pth\x18\x02 \x01(\x04\"o\n\x16ListParametersResponse\x12U\n\x06result\x18\x01 \x01(\x0b\x32\x45.make87_messages_ros2.rolling.rcl_interfaces.msg.ListParametersResultb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rcl_interfaces.srv.list_parameters_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LISTPARAMETERSREQUEST']._serialized_start=200
  _globals['_LISTPARAMETERSREQUEST']._serialized_end=256
  _globals['_LISTPARAMETERSRESPONSE']._serialized_start=258
  _globals['_LISTPARAMETERSRESPONSE']._serialized_end=369
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/msg/motion_sequence_item.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.moveit_msgs.msg import motion_plan_request_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_motion__plan__request__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/moveit_msgs/msg/motion_sequence_item.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.msg\x1a\x44make87_messages_ros2/jazzy/moveit_msgs/msg/motion_plan_request.proto\"v\n\x12MotionSequenceItem\x12J\n\x03req\x18\x01 \x01(\x0b\x32=.make87_messages_ros2.jazzy.moveit_msgs.msg.MotionPlanRequest\x12\x14\n\x0c\x62lend_radius\x18\x02 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.msg.motion_sequence_item_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MOTIONSEQUENCEITEM']._serialized_start=187
  _globals['_MOTIONSEQUENCEITEM']._serialized_end=305
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/geometry_msgs/msg/pose.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import quaternion_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_quaternion__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7make87_messages_ros2/jazzy/geometry_msgs/msg/pose.proto\x12,make87_messages_ros2.jazzy.geometry_msgs.msg\x1a\x38make87_messages_ros2/jazzy/geometry_msgs/msg/point.proto\x1a=make87_messages_ros2/jazzy/geometry_msgs/msg/quaternion.proto\"\x9c\x01\n\x04Pose\x12\x45\n\x08position\x18\x01 \x01(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Point\x12M\n\x0borientation\x18\x02 \x01(\x0b\x32\x38.make87_messages_ros2.jazzy.geometry_msgs.msg.Quaternionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.geometry_msgs.msg.pose_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_POSE']._serialized_start=227
  _globals['_POSE']._serialized_end=383
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TargetA(_message.Message):
    __slots__ = ("header", "can_id", "stamp", "id", "radial_distance", "radial_velocity", "reflected_power", "azimuth_angle", "measured")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CAN_ID_FIELD_NUMBER: _ClassVar[int]
    STAMP_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    RADIAL_DISTANCE_FIELD_NUMBER: _ClassVar[int]
    RADIAL_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    REFLECTED_POWER_FIELD_NUMBER: _ClassVar[int]
    AZIMUTH_ANGLE_FIELD_NUMBER: _ClassVar[int]
    MEASURED_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    can_id: int
    stamp: _time_pb2.Time
    id: int
    radial_distance: float
    radial_velocity: float
    reflected_power: float
    azimuth_angle: float
    measured: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., can_id: _Optional[int] = ..., stamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., id: _Optional[int] = ..., radial_distance: _Optional[float] = ..., radial_velocity: _Optional[float] = ..., reflected_power: _Optional[float] = ..., azimuth_angle: _Optional[float] = ..., measured: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/moveit_msgs/msg/pipeline_state.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.moveit_msgs.msg import motion_plan_request_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_motion__plan__request__pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import motion_plan_response_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_motion__plan__response__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/rolling/moveit_msgs/msg/pipeline_state.proto\x12,make87_messages_ros2.rolling.moveit_msgs.msg\x1a\x46make87_messages_ros2/rolling/moveit_msgs/msg/motion_plan_request.proto\x1aGmake87_messages_ros2/rolling/moveit_msgs/msg/motion_plan_response.proto\"\xcd\x01\n\rPipelineState\x12P\n\x07request\x18\x01 \x01(\x0b\x32?.make87_messages_ros2.rolling.moveit_msgs.msg.MotionPlanRequest\x12R\n\x08response\x18\x02 \x01(\x0b\x32@.make87_messages_ros2.rolling.moveit_msgs.msg.MotionPlanResponse\x12\x16\n\x0epipeline_stage\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.moveit_msgs.msg.pipeline_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_PIPELINESTATE']._serialized_start=261
  _globals['_PIPELINESTATE']._serialized_end=466
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mavros_msgs/srv/mount_configure.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/rolling/mavros_msgs/srv/mount_configure.proto\x12,make87_messages_ros2.rolling.mavros_msgs.srv\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xec\x01\n\x15MountConfigureRequest\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x0c\n\x04mode\x18\x02 \x01(\r\x12\x16\n\x0estabilize_roll\x18\x03 \x01(\x08\x12\x17\n\x0fstabilize_pitch\x18\x04 \x01(\x08\x12\x15\n\rstabilize_yaw\x18\x05 \x01(\x08\x12\x12\n\nroll_input\x18\x06 \x01(\r\x12\x13\n\x0bpitch_input\x18\x07 \x01(\r\x12\x11\n\tyaw_input\x18\x08 \x01(\r\"9\n\x16MountConfigureResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06result\x18\x02 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mavros_msgs.srv.mount_configure_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MOUNTCONFIGUREREQUEST']._serialized_start=173
  _globals['_MOUNTCONFIGUREREQUEST']._serialized_end=409
  _globals['_MOUNTCONFIGURERESPONSE']._serialized_start=411
  _globals['_MOUNTCONFIGURERESPONSE']._serialized_end=468
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class SetAnalogOutputRequest(_message.Message):
    __slots__ = ("index", "voltage")
    INDEX_FIELD_NUMBER: _ClassVar[int]
    VOLTAGE_FIELD_NUMBER: _ClassVar[int]
    index: int
    voltage: float
    def __init__(self, index: _Optional[int] = ..., voltage: _Optional[float] = ...) -> None: ...

class SetAnalogOutputResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...



from make87_messages_ros2.rolling.gps_msgs.msg import gps_status_pb2 as _gps_status_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GPSFix(_message.Message):
    __slots__ = ("header", "status", "latitude", "longitude", "altitude", "track", "speed", "climb", "pitch", "roll", "dip", "time", "gdop", "pdop", "hdop", "vdop", "tdop", "err", "err_horz", "err_vert", "err_track", "err_speed", "err_climb", "err_time", "err_pitch", "err_roll", "err_dip", "position_covariance", "position_covariance_type")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    LATITUDE_FIELD_NUMBER: _ClassVar[int]
    LONGITUDE_FIELD_NUMBER: _ClassVar[int]
    ALTITUDE_FIELD_NUMBER: _ClassVar[int]
    TRACK_FIELD_NUMBER: _ClassVar[int]
    SPEED_FIELD_NUMBER: _ClassVar[int]
    CLIMB_FIELD_NUMBER: _ClassVar[int]
    PITCH_FIELD_NUMBER: _ClassVar[int]
    ROLL_FIELD_NUMBER: _ClassVar[int]
    DIP_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    GDOP_FIELD_NUMBER: _ClassVar[int]
    PDOP_FIELD_NUMBER: _ClassVar[int]
    HDOP_FIELD_NUMBER: _ClassVar[int]
    VDOP_FIELD_NUMBER: _ClassVar[int]
    TDOP_FIELD_NUMBER: _ClassVar[int]
    ERR_FIELD_NUMBER: _ClassVar[int]
    ERR_HORZ_FIELD_NUMBER: _ClassVar[int]
    ERR_VERT_FIELD_NUMBER: _ClassVar[int]
    ERR_TRACK_FIELD_NUMBER: _ClassVar[int]
    ERR_SPEED_FIELD_NUMBER: _ClassVar[int]
    ERR_CLIMB_FIELD_NUMBER: _ClassVar[int]
    ERR_TIME_FIELD_NUMBER: _ClassVar[int]
    ERR_PITCH_FIELD_NUMBER: _ClassVar[int]
    ERR_ROLL_FIELD_NUMBER: _ClassVar[int]
    ERR_DIP_FIELD_NUMBER: _ClassVar[int]
    POSITION_COVARIANCE_FIELD_NUMBER: _ClassVar[int]
    POSITION_COVARIANCE_TYPE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    status: _gps_status_pb2.GPSStatus
    latitude: float
    longitude: float
    altitude: float
    track: float
    speed: float
    climb: float
    pitch: float
    roll: float
    dip: float
    time: float
    gdop: float
    pdop: float
    hdop: float
    vdop: float
    tdop: float
    err: float
    err_horz: float
    err_vert: float
    err_track: float
    err_speed: float
    err_climb: float
    err_time: float
    err_pitch: float
    err_roll: float
    err_dip: float
    position_covariance: _containers.RepeatedScalarFieldContainer[float]
    position_covariance_type: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., status: _Optional[_Union[_gps_status_pb2.GPSStatus, _Mapping]] = ..., latitude: _Optional[float] = ..., longitude: _Optional[float] = ..., altitude: _Optional[float] = ..., track: _Optional[float] = ..., speed: _Optional[float] = ..., climb: _Optional[float] = ..., pitch: _Optional[float] = ..., roll: _Optional[float] = ..., dip: _Optional[float] = ..., time: _Optional[float] = ..., gdop: _Optional[float] = ..., pdop: _Optional[float] = ..., hdop: _Optional[float] = ..., vdop: _Optional[float] = ..., tdop: _Optional[float] = ..., err: _Optional[float] = ..., err_horz: _Optional[float] = ..., err_vert: _Optional[float] = ..., err_track: _Optional[float] = ..., err_speed: _Optional[float] = ..., err_climb: _Optional[float] = ..., err_time: _Optional[float] = ..., err_pitch: _Optional[float] = ..., err_roll: _Optional[float] = ..., err_dip: _Optional[float] = ..., position_covariance: _Optional[_Iterable[float]] = ..., position_covariance_type: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_fleet_msgs/srv/lift_clearance.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/jazzy/rmf_fleet_msgs/srv/lift_clearance.proto\x12-make87_messages_ros2.jazzy.rmf_fleet_msgs.srv\"=\n\x14LiftClearanceRequest\x12\x12\n\nrobot_name\x18\x01 \x01(\t\x12\x11\n\tlift_name\x18\x02 \x01(\t\")\n\x15LiftClearanceResponse\x12\x10\n\x08\x64\x65\x63ision\x18\x01 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_fleet_msgs.srv.lift_clearance_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LIFTCLEARANCEREQUEST']._serialized_start=117
  _globals['_LIFTCLEARANCEREQUEST']._serialized_end=178
  _globals['_LIFTCLEARANCERESPONSE']._serialized_start=180
  _globals['_LIFTCLEARANCERESPONSE']._serialized_end=221
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RecStat(_message.Message):
    __slots__ = ("header", "leap_sec", "clk_reset")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    LEAP_SEC_FIELD_NUMBER: _ClassVar[int]
    CLK_RESET_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    leap_sec: bool
    clk_reset: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., leap_sec: bool = ..., clk_reset: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/mavros_msgs/srv/file_write.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/rolling/mavros_msgs/srv/file_write.proto\x12,make87_messages_ros2.rolling.mavros_msgs.srv\"C\n\x10\x46ileWriteRequest\x12\x11\n\tfile_path\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x04\x12\x0c\n\x04\x64\x61ta\x18\x03 \x03(\r\"5\n\x11\x46ileWriteResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07r_errno\x18\x02 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.mavros_msgs.srv.file_write_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_FILEWRITEREQUEST']._serialized_start=111
  _globals['_FILEWRITEREQUEST']._serialized_end=178
  _globals['_FILEWRITERESPONSE']._serialized_start=180
  _globals['_FILEWRITERESPONSE']._serialized_end=233
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/udp_msgs/srv/udp_socket.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/rolling/udp_msgs/srv/udp_socket.proto\x12)make87_messages_ros2.rolling.udp_msgs.srv\"\x80\x01\n\x10UdpSocketRequest\x12\x15\n\rlocal_address\x18\x01 \x01(\t\x12\x12\n\nlocal_port\x18\x02 \x01(\r\x12\x16\n\x0eremote_address\x18\x03 \x01(\t\x12\x13\n\x0bremote_port\x18\x04 \x01(\r\x12\x14\n\x0cis_broadcast\x18\x05 \x01(\x08\"+\n\x11UdpSocketResponse\x12\x16\n\x0esocket_created\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.udp_msgs.srv.udp_socket_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_UDPSOCKETREQUEST']._serialized_start=106
  _globals['_UDPSOCKETREQUEST']._serialized_end=234
  _globals['_UDPSOCKETRESPONSE']._serialized_start=236
  _globals['_UDPSOCKETRESPONSE']._serialized_end=279
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/example_interfaces/msg/multi_array_layout.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.example_interfaces.msg import multi_array_dimension_pb2 as make87__messages__ros2_dot_jazzy_dot_example__interfaces_dot_msg_dot_multi__array__dimension__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/jazzy/example_interfaces/msg/multi_array_layout.proto\x12\x31make87_messages_ros2.jazzy.example_interfaces.msg\x1aMmake87_messages_ros2/jazzy/example_interfaces/msg/multi_array_dimension.proto\"|\n\x10MultiArrayLayout\x12S\n\x03\x64im\x18\x01 \x03(\x0b\x32\x46.make87_messages_ros2.jazzy.example_interfaces.msg.MultiArrayDimension\x12\x13\n\x0b\x64\x61ta_offset\x18\x02 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.example_interfaces.msg.multi_array_layout_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MULTIARRAYLAYOUT']._serialized_start=208
  _globals['_MULTIARRAYLAYOUT']._serialized_end=332
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_msgs/msg/nav_sbassv.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<make87_messages_ros2/rolling/ublox_msgs/msg/nav_sbassv.proto\x12+make87_messages_ros2.rolling.ublox_msgs.msg\"\x99\x01\n\tNavSBASSV\x12\x0c\n\x04svid\x18\x01 \x01(\r\x12\r\n\x05\x66lags\x18\x02 \x01(\r\x12\x0c\n\x04udre\x18\x03 \x01(\r\x12\x0e\n\x06sv_sys\x18\x04 \x01(\r\x12\x12\n\nsv_service\x18\x05 \x01(\r\x12\x11\n\treserved1\x18\x06 \x01(\r\x12\x0b\n\x03prc\x18\x07 \x01(\x05\x12\x11\n\treserved2\x18\x08 \x01(\r\x12\n\n\x02ic\x18\t \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_msgs.msg.nav_sbassv_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NAVSBASSV']._serialized_start=110
  _globals['_NAVSBASSV']._serialized_end=263
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MutexGroupAssignment(_message.Message):
    __slots__ = ("group", "claimant", "claim_time")
    GROUP_FIELD_NUMBER: _ClassVar[int]
    CLAIMANT_FIELD_NUMBER: _ClassVar[int]
    CLAIM_TIME_FIELD_NUMBER: _ClassVar[int]
    group: str
    claimant: int
    claim_time: _time_pb2.Time
    def __init__(self, group: _Optional[str] = ..., claimant: _Optional[int] = ..., claim_time: _Optional[_Union[_time_pb2.Time, _Mapping]] = ...) -> None: ...
